@@ -25,11 +25,16 @@ from petisco.base.application.notifier.notifier_exception_message import (
 )
 from petisco.base.application.notifier.notifier_message import NotifierMessage
 from petisco.base.application.patterns.app_service import AppService
+from petisco.base.application.patterns.crud_repository import CrudRepository
+from petisco.base.application.patterns.inmemory_crud_repository import (
+    InmemoryCrudRepository,
+)
 from petisco.base.application.patterns.repository import Repository
 from petisco.base.application.use_case.use_case import UseCase
 from petisco.base.application.use_case.use_case_uncontrolled_error import (
     UseCaseUncontrolledError,
 )
+from petisco.base.domain.errors.critical_error import CriticalError
 from petisco.base.domain.errors.default_http_error_map import DEFAULT_HTTP_ERROR_MAP
 from petisco.base.domain.errors.defaults.already_exists import (
     AggregateAlreadyExistError,
@@ -123,6 +128,8 @@ base = [
     "Persistence",
     "PersistenceModels",
     "Repository",
+    "CrudRepository",
+    "InmemoryCrudRepository",
     "AppService",
     "Application",
     "ApplicationConfigurer",
@@ -132,6 +139,7 @@ base = [
 errors = [
     "DEFAULT_HTTP_ERROR_MAP",
     "DomainError",
+    "CriticalError",
     "NotFound",
     "AlreadyExists",
     "AggregateNotFoundError",
